@@ -21,6 +21,12 @@
 #ifndef _CIPHER_CHAOS_H
 #define _CIPHER_CHAOS_H
 #include "dact.h"
+#include "comp_fail.h"
+
+#if defined(USE_MODULES) && !defined(AS_MODULE)
+#define cipher_chaos DACT_FAILED_ALGO
+#else
+
 
 #define R(x) 4*(x)
 #define NORM(x) { x+=0.000001; while(x<1) x*=10; while(x>=1) x/=10; }
@@ -33,3 +39,4 @@ int cipher_chaos_init_getkey(const int mode, char *key);
 int cipher_chaos_encdec(const char *blk, char *outblk, const int blksize, char *key);
 unsigned char cipher_chaos_getbyte(double *x, int y);
 #endif
+#endif
