@@ -21,21 +21,38 @@
 /*
 	Encrypt data.
 */
+#include "cipher_sub.h"
+#include "parse.h"
+#include "dact.h"
+#include "ui.h"
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
 #include <fcntl.h>
 #include <stdio.h>
 #ifndef RANDOM_DEV
 #include <time.h>
 #endif
-#include "cipher_sub.h"
-#include "parse.h"
-#include "dact.h"
-#include "ui.h"
 
+#if defined(USE_MODULES) && defined(AS_MODULE)
+#include "module.h"
+uint32_t DC_NUM=1;
+uint32_t DC_TYPE=DACT_MOD_TYPE_ENC;
+void *DC_ALGO=cipher_sub;
+char *DC_NAME="subst (MOD)";
+#endif
 
 
 int cipher_sub(const char *inblock, char *outblock, const int blksize, char *key, const int mode) {
