@@ -30,7 +30,7 @@
 #define CIPHER_COUNT 5
 #endif
 
-
+#ifdef __DACT_C
 int (*(ciphers[CIPHER_COUNT]))()={
 	cipher_chaos,
 	cipher_sub,
@@ -55,5 +55,9 @@ char *ciphers_name[CIPHER_COUNT]={ 		/* These must be lower-cased */
 	NULL
 };
 
+#else
+extern int (*(ciphers[CIPHER_COUNT]))();
+extern char *ciphers_name[CIPHER_COUNT];
+#endif
 
 #endif
