@@ -22,8 +22,12 @@
 #include "dact.h"
 #include "comp_bitsums.h"
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
 
 
 /*
@@ -37,10 +41,14 @@
 
 
 #if defined(AS_MODULE) && defined(USE_MODULES)
-int DC_NUM=11;
+#include "module.h"
+uint32_t DC_NUM=11;
+uint32_t DC_TYPE=DACT_MOD_TYPE_COMP;
 void *DC_ALGO=comp_bitsums_algo;
 char *DC_NAME="Bitsums Compression (MOD)";
+
 #endif
+
 int comp_bitsums_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
