@@ -21,11 +21,21 @@
 
 #include "dact.h"
 #include "comp_bzlib.h"
+
+#ifdef HAVE_LIBBZ2
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
 #include <stdio.h>
+#ifdef HAVE_BZLIB_H
 #include <bzlib.h>
+#endif
 
 
 /*
@@ -38,7 +48,9 @@
 */
 
 #if defined(USE_MODULES) && defined(AS_MODULE)
-int DC_NUM=9;
+#include "module.h"
+uint32_t DC_NUM=9;
+uint32_t DC_TYPE=DACT_MOD_TYPE_COMP;
 void *DC_ALGO=comp_bzlib_algo;
 char *DC_NAME="Bzip2 Compression (MOD)";
 #endif
@@ -86,9 +98,9 @@ int comp_bzlib_decompress(unsigned char *prev_block, unsigned char *curr_block,
 	memcpy(tmpbuf+4, curr_block, blk_size);
 
 #ifdef HAVE_NEW_BZ2
-	retval=BZ2_bzBuffToBuffDecompress(out_block, &dest_size, tmpbuf, blk_size, 0, 0);
+	retval=BZ2_bzBuffToBuffDecompress(out_block, &dest_size, tmpbuf, blk_size+4, 0, 0);
 #else
-	retval=bzBuffToBuffDecompress(out_block, &dest_size, tmpbuf, blk_size, 0, 0);
+	retval=bzBuffToBuffDecompress(out_block, &dest_size, tmpbuf, blk_size+4, 0, 0);
 #endif
 
 	free(tmpbuf);
@@ -96,3 +108,4 @@ int comp_bzlib_decompress(unsigned char *prev_block, unsigned char *curr_block,
 	if (retval!=BZ_OK) return(0);
 	return(dest_size);
 }
+#endif
