@@ -65,6 +65,12 @@ char *DC_NAME="Second Modified Zlib Compression (MOD)";
 #endif
 
 #ifdef DEBUG
+#if DEBUG>=2
+#define MAKE_MZLIB2 1
+#endif
+#endif
+
+#ifdef MAKE_MZLIB2
 int comp_mzlib2_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	switch(mode) {
 		case DACT_MODE_COMPR:
