@@ -28,11 +28,21 @@
 
 #include "dact.h"
 #include "comp_zlib.h"
+
+#ifdef HAVE_LIBZ
 #include <stdio.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
+#endif
+#ifdef HAVE_STRING_H
 #include <string.h>
+#endif
+#ifdef HAVE_ZLIB_H
 #include <zlib.h>
+#endif
 
 
 /*
@@ -45,7 +55,9 @@
 */
 
 #if defined(USE_MODULES) && defined(AS_MODULE)
-int DC_NUM=4;
+#include "module.h"
+uint32_t DC_NUM=4;
+uint32_t DC_TYPE=DACT_MOD_TYPE_COMP;
 void *DC_ALGO=comp_zlib_algo;
 char *DC_NAME="Zlib Compression (MOD)";
 #endif
@@ -64,7 +76,7 @@ int comp_zlib_algo(int mode, unsigned char *prev_block, unsigned char *curr_bloc
 	}
 }
 
-int comp_zlib_compress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
+int comp_zlib_compress(unsigned char *prev_block, unsigned char *curr_block, unsigned char *out_block, int blk_size) {
 	unsigned long dest_size;
 	int retval;
 	dest_size=(int) ((float) (blk_size*1.01)+13);
@@ -75,20 +87,31 @@ int comp_zlib_compress(unsigned char *prev_block, unsigned char *curr_block, cha
 	retval=compress(out_block, &dest_size, curr_block, blk_size);
 #endif
 	if (retval!=Z_OK) return(-1);
+/* Remove the 120,218 header */
+	dest_size-=2;
+	memmove(out_block, out_block+2, dest_size);
 
 	return(dest_size);
 }
 
 int comp_zlib_decompress(unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size) {
 	unsigned long dest_size;
+	unsigned char *tmpbuf;
 	int retval;
 
+/* Replant the header. */
+	tmpbuf=malloc(blk_size+2);
+	tmpbuf[0]=120;
+	tmpbuf[1]=218;
+	memcpy(tmpbuf+2, curr_block, blk_size);
+
 	dest_size=(DACT_BLK_SIZE*2);
-	retval=uncompress(out_block,&dest_size,curr_block,blk_size);
+	retval=uncompress(out_block,&dest_size,tmpbuf,blk_size+2);
 
+	free(tmpbuf);
+
+	if (retval!=Z_OK) return(0);
 
-	if (retval!=Z_OK) {
-		return(0);
-	}
 	return(dest_size);
 }
+#endif
