@@ -223,7 +223,7 @@ int dact_upgrade_file(const char *name, const char *url_get, const char *url_ver
 	if (newver>version) {
 		if (options[DACT_OPT_UPGRADE]) {
 			fprintf(stderr, "There is a new version of %s.  NEW: %i.%i.%i, CURR: %i.%i.%i, fetching...\n", name, DACT_VER_PARTS(newver), DACT_VER_PARTS(version));
-			if ((ifd=open_net(real_url_get, O_RDONLY))>=0) {
+			if ((ifd=open_net(real_url_get, O_RDONLY, 0))>=0) {
 				if ((ofd=open_net(real_dest, O_WRONLY|O_CREAT|O_TRUNC, S_IRWXU))>=0) {
 					while ((x=read(ifd, buf, sizeof(buf)))>0) {
 						write(ofd, buf, x);
@@ -232,10 +232,10 @@ int dact_upgrade_file(const char *name, const char *url_get, const char *url_ver
 					close(ofd);
 					if (x<0) PERROR("read");
 				} else {
-					PERROR("open");
+					PERROR_L(ofd, "open");
 				}
 			} else {
-				PERROR("open");
+				PERROR_L(ifd, "open");
 			}
 		} else {
 			fprintf(stderr, "There is a new version of %s.  NEW: %i.%i.%i, CURR: %i.%i.%i\n", name, DACT_VER_PARTS(newver), DACT_VER_PARTS(version));
@@ -256,7 +256,7 @@ int dact_upgrade_file_checkver(const char *name, const char *url_ver, const char
 	if (options[DACT_OPT_VERCHK]==0 && options[DACT_OPT_UPGRADE]==0) return(0);
 
 	urlbuf=parse_url_subst(url_ver, name);
-	if ((fd=open_net(urlbuf, O_RDONLY))>=0) {
+	if ((fd=open_net(urlbuf, O_RDONLY, 0))>=0) {
 		read(fd, &verbuf, 9);
 		close(fd);
 		memcpy(rem_vers[0], verbuf, 3);
@@ -410,8 +410,14 @@ int dact_upgrade(const char *options, uint32_t *crcs) {
 	strncat(dact_binfile,"dact.bin",sizeof(dact_binfile)-strlen(dact_binfile)-1);
 #endif
 	urlsubst=parse_url_subst("http://www.rkeene.org/projects/rget/rget.cgi?os=@@OSNM@@&arch=@@ARCH@@&project=dact&file=bin&meth=gz","");
-	if ((outFd=open_net(dact_binfile, O_WRONLY|O_TRUNC|O_CREAT, 0755))<0) { PERROR("open_net"); return(-1); }
-	if ((inFd=open_net(urlsubst, O_RDONLY))<0) { PERROR("open_net"); return(-1); }
+	if ((outFd=open_net(dact_binfile, O_WRONLY|O_TRUNC|O_CREAT, 0755))<0) {
+		PERROR_L(outFd, "open_net");
+		return(-1);
+	}
+	if ((inFd=open_net(urlsubst, O_RDONLY, 0))<0) {
+		PERROR_L(inFd, "open_net");
+		return(-1);
+	}
 	if (!dact_process_file(inFd, outFd, DACT_MODE_DECMP, options, "dact", crcs,-1)) {
 		close(inFd);
 		close(outFd);
@@ -935,7 +941,7 @@ XXX: Todo, make this do something...
 			for (x=0;x<file_extd_urlcnt;x++) {
 				dact_ui_status(DACT_UI_LVL_GEN,"Trying to get remote url ");
 				dact_ui_status_append(DACT_UI_LVL_SPEC, file_extd_urls[x]);
-				if ((new_fd=open_net(file_extd_urls[x],O_RDONLY))<0) {
+				if ((new_fd=open_net(file_extd_urls[x],O_RDONLY,0))<0) {
 					dact_ui_status(DACT_UI_LVL_GEN, "Failed.");
 					continue;
 				}
@@ -1197,7 +1203,7 @@ XXX: Todo, make this do something...
 		for (x=0;x<file_extd_urlcnt;x++) {
 			printf("Download Location :   %s",file_extd_urls[x]);
 			if (options[DACT_OPT_VERB]) {
-				if ((new_fd=open_net(file_extd_urls[x],O_RDONLY))<0) {
+				if ((new_fd=open_net(file_extd_urls[x],O_RDONLY, 0))<0) {
 					printf(" [broken]\n");
 					continue;
 				}
@@ -1451,9 +1457,9 @@ int main(int argc, char **argv) {
 					fprintf(stderr, "dact: %s is a directory.",in_file);
 					continue;
 				}
-				if ((in_fd=open_net(in_file,O_RDONLY))==-1) {
+				if ((in_fd=open_net(in_file, O_RDONLY, 0))<0) {
 					fprintf(stderr, "dact: Can't open %s.\n",in_file);
-					PERROR("open");
+					PERROR_L(in_fd, "open");
 					continue;
 				}
 			}
@@ -1477,9 +1483,9 @@ int main(int argc, char **argv) {
 					continue;
 				}
 				if (!options[DACT_OPT_STDOUT]) {
-					if ((out_fd=open_net(out_file,O_WRONLY|O_CREAT|O_TRUNC,0644))==-1) {
+					if ((out_fd=open_net(out_file,O_WRONLY|O_CREAT|O_TRUNC,0644))<0) {
 						fprintf(stderr, "dact: Can't open %s for writing.\n",out_file);
-						PERROR("open");
+						PERROR_L(out_fd, "open");
 						continue;
 					}
 				}
