@@ -40,8 +40,8 @@
 
 #define DACT_VER_MAJOR 0
 #define DACT_VER_MINOR 8
-#define DACT_VER_REVISION 31
-#define DACT_VERSION "0.8.31"
+#define DACT_VER_REVISION 32
+#define DACT_VERSION "0.8.32"
 #ifdef DEBUG
 #define DACT_VER_SUB	"dev"
 #else
@@ -92,7 +92,7 @@
 #define DACT_HDR_IDXDATA	11
 
 #ifndef DACT_BLK_SIZE_MAX
-#define DACT_BLK_SIZE_MAX 4294967296
+#define DACT_BLK_SIZE_MAX 2147483647
 #define MAX_DACT_BLK_SIZE DACT_BLK_SIZE_MAX
 #endif
 #ifndef DACT_BLK_SIZE_DEF
@@ -115,6 +115,9 @@
 #ifdef HAVE_INTTYPES_H
 #include <inttypes.h>
 #endif
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
 
 #define DACT_MAGIC_NUMBER 0x444354C3
 #define DACT_MAGIC_OFFSET 0
@@ -132,26 +135,31 @@ extern uint32_t DACT_BLK_SIZE;
 extern char dact_nonetwork;
 
 #if defined(__FILE__) && defined(__LINE__) && defined(DEBUG)
-#define PRINT_LINE fprintf(stderr, __FILE__ ":%07i: ", __LINE__)
+#define PRINT_LINE fprintf(stderr, "%s:%07i:%s(): ", __FILE__, __LINE__, __func__)
 #else
 #define PRINT_LINE /**/
 #endif
 
 #define PERROR(error) { PRINT_LINE; perror("dact: " error); }
+#define PERROR_L(errnum, error) { PRINT_LINE; fprintf(stderr, "%s: %s\n", error, strerror(abs(errnum))); }
 #define PRINTERR(error) { PRINT_LINE; fprintf(stderr, "dact: " error "\n"); }
 
 /* Win32 check here */
+
+
 #define SANITY(x, y...) { if ((x(y))<0) { PERROR(#x); return(-1); } }
 #ifdef DEBUG
-#define SHOWVAL(x...) PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) (x))
-#define SPOTVAR_NUM(x) PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) x)
-#define SPOTVAR_STR(x) PRINT_LINE; fprintf(stderr, "dact: %s=\"%s\"\n", #x, x)
+#define SHOWVAL(x...) { PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) (x)); }
+#define SPOTVAR_NUM(x) { PRINT_LINE; fprintf(stderr, "dact: %s=%li\n", #x, (long) x); }
+#define SPOTVAR_STR(x) { PRINT_LINE; fprintf(stderr, "dact: %s=\"%s\"\n", #x, x); }
 #define CHECKPOINT PRINTERR("Checkpoint reached.")
+#define DPRINTF(x...) { PRINT_LINE; fprintf(stderr, x); fprintf(stderr, "\n"); }
 #else
 #define SHOWVAL(x...) x
 #define SPOTVAR_NUM(x) /**/
 #define SPOTVAR_STR(x) /**/
 #define CHECKPOINT /**/
+#define DPRINTF(x...) /**/
 #endif
 
 #ifndef DACT_FAILED_ALGO
